import * as react_jsx_runtime from 'react/jsx-runtime';
import { IConversationModel } from '@tencentcloud/chat-uikit-engine';
import { IConversationSearchInputProps } from './ConversationSearchInput/ConversationSearchInput.js';
import { IConversationSearchResultProps } from './ConversationSearchResult/ConversationSearchResult.js';
import { IConversationPreviewProps } from '../ConversationPreview/ConversationPreview.js';
import { AvatarProps } from '../Avatar/Avatar.js';

interface IConversationSearchProps {
    /** The list of conversations to be searched. */
    conversationList: IConversationModel[];
    /** Specifies a react component to customize the avatar in the search results. */
    Avatar?: React.ComponentType<AvatarProps>;
    /** Specifies a react component to customize the preview of search results. */
    ResultPreview?: React.ComponentType<IConversationPreviewProps>;
    /** Specifies a react component to customize the search input. */
    ConversationSearchInput?: React.ComponentType<IConversationSearchInputProps>;
    /** Specifies a react component to customize the search result. */
    ConversationSearchResult?: React.ComponentType<IConversationSearchResultProps>;
    /** Specifies a function to customize the search algorithm. This function takes the search value and the conversation list as parameters and returns the search results. */
    searchFn?: (searchValue: string, conversationList: IConversationModel[]) => IConversationModel[];
    /** Specifies a function to be called when the search input changes. This function takes the current search value as a parameter. */
    onSearchChange?: (searchValue: string) => void;
    /** Specifies a function to be called when the search input is focused. */
    onFocus?: (event: React.FocusEvent<HTMLInputElement>) => void;
    /** Specifies a function to be called when the search input is blurred. */
    onBlur?: (event: React.FocusEvent<HTMLInputElement>) => void;
    /** Specifies a function to be called when a search result is selected. This function takes the selected conversation as a parameter. */
    onSelectResult?: (conversation: IConversationModel) => void;
    /** Specifies whether the search component is visible. */
    visible?: boolean;
    /** Specifies a custom class name for the search component. */
    className?: string;
    /** The custom css style */
    style?: React.CSSProperties;
}
declare function defaultSearchFn(searchValue: string, conversationList: IConversationModel[]): IConversationModel[];
declare function ConversationSearch(props: IConversationSearchProps): react_jsx_runtime.JSX.Element | null;

export { ConversationSearch, IConversationSearchProps, defaultSearchFn };
