import * as react_jsx_runtime from 'react/jsx-runtime';
import React__default from 'react';
import { IConversationModel } from '@tencentcloud/chat-uikit-engine';

interface IConversationActionsConfig {
    /** Determines whether the pin button appears on the conversation actions list view. (Default: True) */
    enablePin?: boolean;
    /**  Determines whether the mute button appears on the conversation actions list view. (Default: True) */
    enableMute?: boolean;
    /** Determines whether the delete button appears on the conversation actions list view. (Default: True) */
    enableDelete?: boolean;
    /** Function to override the default behavior when user pin or unpin a conversation.  */
    onConversationPin?: (conversation: IConversationModel, e?: React__default.MouseEvent) => void;
    /** Function to override the default behavior when user mute or unmute a conversation. */
    onConversationMute?: (conversation: IConversationModel, e?: React__default.MouseEvent) => void;
    /** Function to override the default behavior when user delete a conversation. */
    onConversationDelete?: (conversation: IConversationModel, e?: React__default.MouseEvent) => void;
    /**
     * An object containing custom conversation actions (key) and object (value).
     * Each value is an object with the following properties:
     * enable: Determines whether the custom action is enabled. (Default: True)
     * label: The label of the custom action.
     * onClick: The function to be called when the custom action is clicked.
     * Note: The key of the custom action must be unique.
     */
    customConversationActions?: Record<string, IConversationActionItem>;
    /** The icon react element to be displayed in the action popup. */
    PopupIcon?: React__default.ReactElement;
    /** An array of react elements to be displayed in the action popup. */
    PopupElements?: React__default.ReactElement[];
    /** The function to be called when the action popup is clicked. */
    onClick?: (e: React__default.MouseEvent, key?: string, conversation?: IConversationModel) => void;
}
interface IConversationActionsProps extends IConversationActionsConfig {
    /** The conversation model. */
    conversation: IConversationModel;
    /** The class name of the root element. */
    className?: string;
    /** The style of the root element. */
    style?: React__default.CSSProperties;
}
interface IConversationActionItem {
    /** Determines whether the custom action is enabled. (Default: True)  */
    enable?: boolean;
    /** label: The label of the custom action. */
    label: string;
    /** onClick: The function to be called when the custom action is clicked. */
    onClick: (conversation: IConversationModel, e?: React__default.MouseEvent) => void;
}
declare const ConversationActions: (props: IConversationActionsProps) => react_jsx_runtime.JSX.Element;

export { ConversationActions, IConversationActionItem, IConversationActionsConfig, IConversationActionsProps };
