import React__default, { PropsWithChildren } from 'react';
import { IConversationModel, CreateGroupParams } from '@tencentcloud/chat-uikit-engine';
import { IConversationListHeaderProps } from './ConversationListHeader/ConversationListHeader.js';
import { IConversationListContentProps } from './ConversationListContent/ConversationListContent.js';
import { IConversationPreviewUIProps } from '../ConversationPreview/ConversationPreview.js';
import { AvatarProps } from '../Avatar/Avatar.js';
import { IConversationSearchProps } from '../ConversationSearch/ConversationSearch.js';
import { IConversationCreateProps } from '../ConversationCreate/ConversationCreate.js';
import { IConversationActionsConfig, IConversationActionsProps } from '../ConversationActions/ConversationActions.js';

interface IConversationListProps {
    /** Determines whether the conversation search input appears on the conversation list view. (Default: True) */
    enableSearch?: boolean;
    /** Determines whether the conversation creation button appears on the conversation list view. (Default: True) */
    enableCreate?: boolean;
    /** Determines whether the conversation action button appears on the conversation list view. (Default: True) */
    enableActions?: boolean;
    /** Specifies the prop to customize action on the conversation list item. */
    actionsConfig?: IConversationActionsConfig;
    /** Specifies a react component to customize the header of the conversation list. */
    Header?: React__default.ComponentType<IConversationListHeaderProps>;
    /** Specifies a react component to customize the conversation list component. */
    List?: React__default.ComponentType<IConversationListContentProps>;
    /** Specifies a react component to customize the conversation preview. */
    Preview?: React__default.ComponentType<IConversationPreviewUIProps>;
    /** Specifies a react component to customize the conversation create component. */
    ConversationCreate?: React__default.ComponentType<IConversationCreateProps>;
    /** Specifies a react component to customize the conversation search. */
    ConversationSearch?: React__default.ComponentType<IConversationSearchProps>;
    /** Specifies a react component to customize the conversation actions in conversation preview. */
    ConversationActions?: React__default.ComponentType<IConversationActionsProps>;
    /** Specifies a react component to customize the placeholder when the conversation list is empty. */
    PlaceholderEmptyList?: React__default.ReactNode;
    /** Specifies a react component to customize the placeholder when the conversation list is loading. */
    PlaceholderLoading?: React__default.ReactNode;
    /** Specifies a react component to customize the placeholder when the conversation list loaded error. */
    PlaceholderLoadError?: React__default.ReactNode;
    /** Specifies a react component to customize the avatar in list. */
    Avatar?: React__default.ComponentType<AvatarProps>;
    /** Specifies a function to filter conversations in the conversation list. */
    filter?: (conversationList: IConversationModel[]) => IConversationModel[];
    /** Specifies a function to sort conversations in the conversation list. */
    sort?: (conversationList: IConversationModel[]) => IConversationModel[];
    /** Specifies the prop to receive callback when a user clicks a conversation in the conversation list. */
    onSelectConversation?: (conversation: IConversationModel) => void;
    /** Specifies the prop to execute custom operations before creating a channel. */
    onBeforeCreateConversation?: (params: string | CreateGroupParams) => string | CreateGroupParams;
    /** Specifies the prop to receive callback when a conversation is created. */
    onConversationCreated?: (conversation: IConversationModel) => void;
    /** The custom class name */
    className?: string;
    /** The custom css style */
    style?: React__default.CSSProperties;
}
declare function ConversationList<T extends IConversationListProps>(props: PropsWithChildren<T>): React__default.ReactElement;

export { ConversationList, IConversationListProps };
