import React__default, { CSSProperties } from 'react';
import { IConversationModel } from '@tencentcloud/chat-uikit-engine';
import { AvatarProps } from '../Avatar/Avatar.js';
import { IConversationActionsProps, IConversationActionsConfig } from '../ConversationActions/ConversationActions.js';

interface IConversationPreviewUIProps {
    /** The conversation to be displayed */
    conversation: IConversationModel;
    /** If the component's Conversation is the active (selected) Conversation */
    isSelected?: boolean;
    /** Whether to show the ConversationActions */
    enableActions?: boolean;
    /** The string to be highlighted in the title */
    highlightMatchString?: string;
    /** The custom Avatar component */
    Avatar?: React__default.ComponentType<AvatarProps>;
    /** The custom Title component */
    Title?: string | JSX.Element;
    /** The custom last message abstract component */
    LastMessageAbstract?: string | JSX.Element;
    /** The custom last message abstract component */
    LastMessageTimestamp?: string | JSX.Element;
    /** The custom Unread component */
    Unread?: string | JSX.Element;
    /** The custom ConversationActions component */
    ConversationActions?: React__default.ComponentType<IConversationActionsProps>;
    /** Callback when the user click a conversation from conversation list */
    onSelectConversation?: (conversation: IConversationModel) => void;
    /** The custom ConversationActions config */
    actionsConfig?: IConversationActionsConfig;
    /** The custom class name */
    className?: string;
    /** The custom class style */
    style?: CSSProperties;
    /** The custom children node to override UI */
    children?: React__default.ReactNode;
}
interface IConversationPreviewProps extends IConversationPreviewUIProps {
    /** The custom Preview UI component */
    Preview?: React__default.ComponentType<IConversationPreviewUIProps>;
}
declare function ConversationPreview<T extends IConversationPreviewProps>(props: T): React__default.ReactElement;
declare function ConversationPreviewUI<T extends IConversationPreviewUIProps>(props: T): React__default.ReactElement;

export { ConversationPreview, ConversationPreviewUI, IConversationPreviewProps, IConversationPreviewUIProps };
